DEFAULT_OPTIONS = {"initialized": False}
DEFAULT_DELAY = 0.5
RETRY_DELAY = 5
FIELD_SPLITTER = "."
DEFAULT_RETRY_COUNT = 5

FILE_SIZE_DOWNLOAD_LIMIT = 270000000
DEFAULT_TIMEOUT = 120
PARAM_SPLITTER = ";"

DEFAULT_ERROR_STATUS_CODES = [500, 502, 503]
